@@ -58,7 +58,7 @@ Sends the Rovio a halt message.
 
 =head1 DEPENDENCIES
 
-WWW::Mechanize
+WWw::Mechanize
 
 =head1 TODO
 
@@ -72,7 +72,7 @@ Ivan Greene (ivantis@ivantis.net)
 
 =head1 SEE ALSO
 
-WWW::Mechanize
+WWW::Mechanize(3pm)
 
 =cut
 
@@ -80,7 +80,7 @@ use strict;
 use warnings;
 use WWW::Mechanize;
 use vars qw($VERSION);
-$VERSION = "0.8.1";
+$VERSION = "0.6";
 
 sub new {
   my $package = shift;
@@ -98,7 +98,7 @@ sub new {
 sub send {
   my $self = shift;
   if ($self->{'opened'}) {
-    if ($_[0] ne "") {
+    if ($_[0] && $_[1]) {
       my $request = WWW::Mechanize->new();
       my $auth;
       if ($self->{'auth'}) {
